import requests


def request(url, header=None, params=None, verify=None, method='get'):
    if method == 'get':
        return requests.get(url, headers=header, params=params, verify=verify)
    elif method == 'post':
        return requests.post(url, params)


def request_json(url, header=None, params=None, verify=None, method='get'):
    response = request(url, header, params, verify, method)
    return response.json()



from firstimpression.scala import variables
from firstimpression.constants import TEMP_FOLDER
from socketIO_client import SocketIO, LoggingNamespace
import socket
import os

svars = variables()

class SocketClient:

    def __init__(self, name, port=443):
        self.name = name
        self.base_name = f'FI_{name}_'
        self.server = 'https://192.168.99.240'
        self.port = port
        self.socket = SocketIO(self.server, self.port, LoggingNamespace, verify=False, wait_for_connection=False)
    
    def change_triggers(self, *args):
        for key in svars:
            if self.base_name in key:
                svars[key] = False

        if not args[0] == f'{self.base_name}01' and self.base_name in args[0]:
            svars[f'Channel.{args[0]}'] = True

    def check_triggers(self):
        self.socket.on(self.name, self.change_triggers)

    def check_prices(self):
        self.socket.on('general', SocketClient.show_prices)
    
    def wait(self):
        self.socket.wait()

    @staticmethod
    def show_prices(*args):
        if args[0] == 'showprices':
            svars['Channel.showprices'] = True
    
        if args[0] == 'resetprices':
            svars['Channel.showprices'] = False

class Socket:

    def __init__(self, name, port, triggers=True, alarm=False, prices=False):
        self.triggers = triggers
        self.alarm = alarm
        self.prices = prices
        self.name = name
        self.base_name = f'FI_{name}_'
        self.ip = socket.gethostbyname(socket.gethostname())
        self.port = port
        self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        self.buffer_size = 1024

        self.socket.bind((self.ip, self.port))

    def get_data(self):
        return self.socket.recvfrom(self.buffer_size)
    
    def check_data(self):
        data, addr = self.get_data()
        if self.triggers:
            self.check_triggers(data)
        if self.alarm:
            self.check_alarm(data)
        if self.prices:
            Socket.check_prices(data)

    def check_triggers(self, data):
        if self.base_name in data:
            for key in svars:
                if self.base_name in key:
                    svars[key] = False
            
            if not data == f'{self.base_name}01':
                svars[f'Channel.{data}'] = True
    
    def check_alarm(self, data):
        if data == 'alarm_on':
            svars[f'Channel.{self.base_name}off'] = True
        elif data == 'alarm_off':
            svars[f'Channel.{self.base_name}off'] = False
    
    @staticmethod
    def check_prices(data):
        if data == 'showprices':
            svars['Channel.showprices'] = True
    
        if data == 'resetprices':
            svars['Channel.showprices'] = False
            
            













import xml.etree.ElementTree as ET
import glob
import os

from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, IMG_EXTENSIONS, VIDEO_EXTENSIONS, DUTCH_INDEX
from firstimpression.file import create_directories, write_root_to_xml_files, update_directories_api, check_too_old, list_files, download_install_media
from firstimpression.time import change_language, parse_date_to_string, parse_timestamp_to_date
from firstimpression.scala import variables, Log
from firstimpression.api.request import request_json

##################################################################################################
# LOGGING
##################################################################################################

script = 'Weather'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['weather']

XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, 'weather.xml')
XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'weather*.xml')

MAX_FILE_AGE = 60 * 60
MAX_FILE_AGE_IMAGES = 60 * 60 * 24

URL_TODAY = 'http://api.openweathermap.org/data/2.5/weather'
URL_DAYS = 'http://api.openweathermap.org/data/2.5/forecast/daily'

TEMPERATURE_DECIMALS = 1

#http://openweathermap.org/weather-conditions
VIDEOS = {
    'wvideo_cloudy': {803, 804},
    'wvideo_fog': {701, 711, 721, 731, 741, 751, 761, 762, 771, 781},
    'wvideo_pcloudy': {801, 802},
    'wvideo_rain': {300, 301, 302, 310, 311, 312, 313, 314, 321, 500, 501, 502, 503, 504, 511, 520, 521, 522, 531},
    'wvideo_snow': {600, 601, 602, 611, 612, 615, 616, 620, 621, 622},
    'wvideo_sunny': {800},
    'wvideo_tstorms': {200, 201, 202, 210, 211, 212, 221, 230, 231, 232},
    'wvideo_extreme': {900, 901, 902, 903, 904, 905, 906},
    'wvideo_additional': {951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962}
}
#icons
ICONS = {
    "01": {800, 951},
    "02": {801, 802},
    "03": {803, 804},
    "04": {301, 302, 311, 312},
    "05": {300, 310},
    "06": {313, 314, 321},
    "07": {500, 501},
    "08": {906, 511},
    "09": {},
    "10": {502, 503, 504, 521, 522, 531},
    "11": {520},
    "12": {201, 202, 211, 212, 221, 231, 232},
    "13": {200, 210, 230},
    "14": {602, 611, 612, 616, 621},
    "15": {600, 601, 615, 620},
    "16": {900, 901, 902, 905, 954, 955, 956, 957, 958, 959, 960, 961, 962},
    "17": {952, 953},
    "18": {622},
    "19": {701, 711, 721, 731, 741, 751, 761, 762, 771, 781},
    "unknown": {903, 904}
}

TAGS = {
    'location': 'name',
    'clouds': 'clouds',
    'clouds_%': 'all',
    'rain': 'rain',
    '3hours': '3h',
    'snow': 'snow',
    'wind': 'wind',
    'wind_speed': 'speed',
    'wind_angle': 'deg',
    'info': 'main',
    'humidity': 'humidity',
    'pressure': 'pressure',
    'max_temp': 'temp_max',
    'min_temp': 'temp_min',
    'current_temp': 'temp',
    'weather': 'weather',
    'status': 'main',
    'description': 'description',
    'id': 'id',
    'icon': 'icon',
    'days': 'list',
    'date': 'dt',
    'temp': 'temp',
    'temp_max': 'max',
    'temp_min': 'min'
}

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(api_key, icon_set, location='', units='metric', lang='nl', coordinates=None):
    params = {
        'q': location,
        'appid': api_key, 
        'units': units,
        'lang': lang
    }

    if not coordinates is None:
        del params['q']
        params['lon'] = coordinates['longitude']
        params['lat'] = coordinates['latitude']

    url_icons = 'https://fi-api.io/weather_images/{}'.format(icon_set)

    extensions = IMG_EXTENSIONS + VIDEO_EXTENSIONS
    
    temp_folder_icons = os.path.join(TEMP_FOLDER, NAME, 'icons', icon_set)
    local_folder_icons = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'icons', icon_set)

    debug.log('folder name: {}'.format(NAME))
    debug.log('params: {} - url icons: {} - extensions: {}'.format(params, url_icons, extensions))
    debug.log('folder icons temp: {} - local: {}'.format(temp_folder_icons, local_folder_icons))

    create_directories([temp_folder_icons, local_folder_icons])
    update_directories_api(NAME)
    change_language(DUTCH_INDEX)

    if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):

        download_icons(url_icons, extensions, temp_folder_icons, icon_set)
        
        root = ET.Element("root")

        current_weather = request_json(URL_TODAY, params=params)

        item = ET.SubElement(root, 'currentWeather')
        ET.SubElement(item, "location").text = get_location(current_weather)
        ET.SubElement(item, "clouds").text = get_clouds(current_weather)
        ET.SubElement(item, "rain").text = get_rain(current_weather)
        ET.SubElement(item, "snow").text = get_snow(current_weather)
        ET.SubElement(item, "wind_speed").text = get_wind_speed(current_weather)
        ET.SubElement(item, "wind_deg").text = get_wind_angle(current_weather)
        ET.SubElement(item, "humidity").text = get_humidity(current_weather)
        ET.SubElement(item, "pressure_press").text = get_pressure(current_weather)
        ET.SubElement(item, "temperature_max").text = get_max_temperature(current_weather)
        ET.SubElement(item, "temperature_min").text = get_min_temperature(current_weather)
        ET.SubElement(item, "temperature_current").text = get_current_temperature(current_weather)
        ET.SubElement(item, "status").text = get_status(current_weather)
        ET.SubElement(item, "detailed_status").text = get_detailed_status(current_weather)
        ET.SubElement(item, "code").text = str(get_code(current_weather))
        ET.SubElement(item, "day").text = get_isday(current_weather)
        ET.SubElement(item, "video").text = get_video(current_weather, icon_set)
        ET.SubElement(item, "icon").text = get_icon(current_weather, icon_set)

        params['cnt'] = 6

        days_weather = request_json(URL_DAYS, params=params)

        days = ET.SubElement(root, "days")

        for day in get_days(days_weather):
            item = ET.SubElement(days, "day")
            ET.SubElement(item, "date").text = get_date_formated(day)
            ET.SubElement(item, "weekday").text = get_weekday(day)
            ET.SubElement(item, "detailed_status").text = get_detailed_status(day)
            ET.SubElement(item, "rain").text = get_rain(day)
            ET.SubElement(item, "snow").text = get_snow(day)
            ET.SubElement(item, "temperature_max").text = get_max_temperature(day)
            ET.SubElement(item, "temperature_min").text = get_min_temperature(day)
            ET.SubElement(item, "video").text = get_video(day, icon_set)
            ET.SubElement(item, "icon").text = get_icon(day, icon_set)

        write_root_to_xml_files(root, XML_TEMP_PATH, NAME)
    else:
        debug.log('File not old enough to update')

def check_api():

    svars = variables()

    file_path = glob.glob(XML_LOCAL_PATH)

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, MAX_FILE_AGE):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################

def download_icons(url_icons, extensions, temp_folder_icons, icon_set):
    links = list_files(url_icons, extensions)

    for link in links:
        debug.log('icon link: {}'.format(link))
        file_name = link.split('/')[-1]
        if check_too_old(os.path.join(temp_folder_icons, file_name), MAX_FILE_AGE_IMAGES):
            download_install_media(link, TEMP_FOLDER, '{}\\icons\\{}'.format(NAME, icon_set))


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_location(current_weather):
    return current_weather.get(TAGS['location'], '')

def get_clouds(current_weather):
    percentage = current_weather.get(TAGS['clouds'], {}).get(TAGS['clouds_%'], '?')
    return '{}%'.format(percentage)

def get_rain(weather):
    rain = weather.get(TAGS['rain'], 0)

    if rain == 0:
        return '0 mm'
    elif isinstance(rain, dict):
        return '{} mm'.format(rain.get(TAGS['3hours'], 0))
    else:
        return '{} mm'.format(rain)

def get_snow(weather):
    snow = weather.get(TAGS['snow'], 0)

    if snow == 0:
        return '0 mm'
    elif isinstance(snow, dict):
        return '{} mm'.format(snow.get(TAGS['3hours'], '0'))
    else:
        return '{} mm'.format(snow)

def get_wind(current_weather):
    return current_weather.get(TAGS['wind'], {})

def get_wind_speed(current_weather):
    wind = get_wind(current_weather)
    return '{} m/s'.format(wind.get(TAGS['wind_speed'], '?'))

def get_wind_angle(current_weather):
    wind = get_wind(current_weather)
    return '{}'.format(wind.get(TAGS['wind_angle'], '?'))

def get_weather_info(current_weather):
    return current_weather.get(TAGS['info'], {})

def get_humidity(current_weather):
    info = get_weather_info(current_weather)
    return '{}%'.format(info.get(TAGS['humidity'], '?'))

def get_pressure(current_weather):
    info = get_weather_info(current_weather)
    return '{} hpa'.format(info.get(TAGS['pressure'], '?'))

def get_temperature(day):
    return day.get(TAGS['temp'], {})


def get_max_temperature(weather):
    info = get_weather_info(weather)

    if not bool(info):
        #if the info is empty
        temp = get_temperature(weather)
        return '{}'.format(round_temperature(temp.get(TAGS['temp_max'], '?')))
    else:
        return '{}'.format(round_temperature(info.get(TAGS['max_temp'], '?')))
        

def get_min_temperature(weather):
    info = get_weather_info(weather)

    if not bool(info):
        #if the info is empty
        temp = get_temperature(weather)
        return '{}'.format(round_temperature(temp.get(TAGS['temp_min'], '?')))
    else:
        return '{}'.format(round_temperature(info.get(TAGS['min_temp'], '?')))

def get_current_temperature(current_weather):
    info = get_weather_info(current_weather)
    return '{}'.format(round_temperature(info.get(TAGS['current_temp'], '?')))

def get_weather(current_weather):
    return current_weather.get(TAGS['weather'], [{}])[0]

def get_status(current_weather):
    weather = get_weather(current_weather)
    return weather.get(TAGS['status'], '')

def get_detailed_status(weather_):
    weather = get_weather(weather_)
    return weather.get(TAGS['description'], '')

def get_code(weather_):
    weather = get_weather(weather_)
    return weather.get(TAGS['id'], 0)

def get_icon_name(weather_):
    weather = get_weather(weather_)
    return weather.get(TAGS['icon'], '')

def get_isday(weather):
    icon_name = get_icon_name(weather)
    if 'd' in icon_name:
        return 'True'
    elif 'n' in icon_name:
        return 'False'
    else:
        return 'True'

def get_day_letter(weather):
    if get_isday(weather) == 'True':
        return 'd'
    else:
        return 'n'

    
def get_video(weather, icon_set):
    code = get_code(weather)
    letter = get_day_letter(weather)

    if code == 0:
        return 'Content:\\placeholders\\video.png'
    else:
        for key,value in VIDEOS.items():
            if code in value:
                return 'Content:\\{}\\icons\\{}\\{}{}.mp4'.format(NAME, icon_set, key, letter)

def get_icon(weather, icon_set):
    code = get_code(weather)
    letter = get_day_letter(weather)

    if code == 0:
        return 'Content:\\placeholders\\img.png'
    else:
        for key,value in ICONS.items():
            if code in value:
                return 'Content:\\{}\\icons\\{}\\{}{}.png'.format(NAME, icon_set, key, letter)

def get_days(days_weather):
    return days_weather.get(TAGS['days'], [])

def get_date(day):
    return parse_timestamp_to_date(day.get(TAGS['date'], 0))

def get_date_formated(day):
    return parse_date_to_string(get_date(day), '%d-%b-%Y')

def get_weekday(day):
    return parse_date_to_string(get_date(day), '%A')


##################################################################################################
# PARSE FUNCTIONS
##################################################################################################

def round_temperature(temp):
    if isinstance(temp, str):
        return temp
    else:
        return round(temp, TEMPERATURE_DECIMALS)



import xml.etree.ElementTree as ET
import os
import glob
import unidecode

from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, PICTURE_FORMATS, TAGS_TO_REMOVE, REPLACE_DICT
from firstimpression.file import update_directories_api, create_directories, check_too_old, write_root_to_xml_files, list_files_dir, download_media, xml_to_root
from firstimpression.rss import get_feed
from firstimpression.text import remove_tags_from_string
from firstimpression.xml import get_attrib_from_element
from firstimpression.scala import variables, Log, install_content

from w3lib.html import replace_entities
##################################################################################################
# LOGGING
##################################################################################################

script = 'Interia'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['news_polish']

RSSFEED_URL = {
    'sport': 'https://sport.interia.pl/feed',
    'polska': 'https://wydarzenia.interia.pl/polska/feed',
    'kultura': 'https://wydarzenia.interia.pl/kultura/feed'
}

TAGS = {
    'item': 'channel/item',
    'title': 'title',
    'description': 'description'
}

LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME)

MAX_ITEMS = 4
MAX_FILE_AGE = 60 * 10

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################


def run_api(news_categories, minimal_items):

    debug.log('folder name: {}'.format(NAME))

    update_directories_api(NAME)

    minimal_items = MAX_ITEMS if minimal_items > MAX_ITEMS else minimal_items

    debug.log('minimal_items: {}'.format(minimal_items))

    for news_category in news_categories:
        if news_category == '' or news_category is None:
            warn.log('news category is empty')
            continue

        category = news_category.lower()
        url = RSSFEED_URL[category]
        xml_temp_path = os.path.join(
            TEMP_FOLDER, NAME, '{}.xml'.format(category))

        debug.log(
            'category: {} - url: {} - temp path: {}'.format(category, url, xml_temp_path))

        create_directories([
            os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, category),
            os.path.join(TEMP_FOLDER, NAME, category)])

        if check_too_old(xml_temp_path, MAX_FILE_AGE):
            root = ET.Element("root")
            feed = get_feed(url)

            for news_item in feed.findall(TAGS['item']):
                item = ET.SubElement(root, "item")
                ET.SubElement(item, "title").text = get_title(news_item)
                ET.SubElement(
                    item, "description").text = get_description(news_item)

                media_link = install_picture_content_wrap('square', os.path.join(
                    NAME, category), TEMP_FOLDER, news_item, 'enclosure', 'url')

                if not media_link:
                    debug.log('image not found using placeholder')
                    media_link = 'Content:\\placeholders\\img.png'

                ET.SubElement(item, "picsqr").text = media_link

                if len(root) == MAX_ITEMS:
                    debug.log('max amount of items reached')
                    break

            if len(root) >= minimal_items:
                write_root_to_xml_files(root, xml_temp_path, NAME)
            else:
                warn.log('not enough news items found to store to xml file')


def check_api(news_categories):
    svars = variables()

    for category in news_categories:
        debug.log('category: {}'.format(category))
        file_path = glob.glob(os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, '{}*.xml'.format(category.lower())))
        
        if len(file_path) > 0:
            file_path = file_path[0]
            debug.log('glob filepath: {}'.format(file_path))

            if check_too_old(file_path, MAX_FILE_AGE):
                svars['skipscript'] = True
                info.log('file too old')
                break
            else:
                svars['skipscript'] = False

                svars['total_items'] = len(xml_to_root(file_path))
                svars['total_categories'] = len(news_categories)

                if svars['total_items'] == 0 or svars['total_categories'] == 0:
                    svars['skipscript'] = True
                    warn.log('total_items or total_categories is empty')
                    break
        else:
            warn.log('File does not exists')
            svars['skipscript'] = True


##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################

def install_picture_content_wrap(picture_format, subdirectory, temp_folder, element, tag, attrib):
    # Installs content to LocalIntegratedContent folder and returns mediapath
    if not picture_format in PICTURE_FORMATS:
        return None

    media_link = get_attrib_from_element(
        element, tag, attrib).replace("_sqr256", "")

    media_path = download_media(
        PICTURE_FORMATS[picture_format] + media_link, subdirectory, temp_folder)

    install_content(media_path, subdirectory)

    media_filename = media_path.split('\\').pop()

    return os.path.join('Content:\\', subdirectory, media_filename)

##################################################################################################
# GET FUNCTIONS
##################################################################################################


def get_title(news_item):
    return unidecode.unidecode(replace_entities(news_item.findtext(TAGS['title'], '')))


def get_description(news_item):
    return unidecode.unidecode(replace_entities(remove_tags_from_string(TAGS_TO_REMOVE, news_item.findtext(TAGS['description'], ''))))

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################



import datetime
import time
import locale
from firstimpression.xml import get_text_from_element
from firstimpression.constants import ENGLISH_INDEX, DUTCH_INDEX


def change_language(language_index):
    if language_index == ENGLISH_INDEX:
        language = 'en_US'
        try:
            locale.setlocale(locale.LC_TIME, language)
        except locale.Error:
            language = 'English_America'
            locale.setlocale(locale.LC_TIME, language)
    elif language_index == DUTCH_INDEX:
        language = 'nl_NL'
        try:
            locale.setlocale(locale.LC_TIME, language)
        except locale.Error:
            language = 'Dutch_Netherlands'
            locale.setlocale(locale.LC_TIME, language)

def get_datetime_object_from_element(element, name, format):
    """ Gets the datetime object of an element (xml) based on name and format

    :param element: the element from which the date needs to be grabbed
    :type element: xml.etree.ElementTree.Element

    :param name: name of the element in xml which contains date
    :type name: str

    :param format: the format of the datetime in the element
    :type format: str

    :returns: time and date in the right format
    :rtype: date
     """
    unparsed_pubdate = get_text_from_element(element, name)

    created_at = parse_string_to_time(element, format)
    return parse_timestamp_to_date(created_at)


def parse_string_to_time(element, format):
    """ Gets the timestamp of an string in specific format

    :param element: string with the time in it
    :type element: str

    :param format: string with the format devined
    :type format: str

    :returns: time as timestamp
    :rtype: float """
    return parse_date_to_time(parse_string_to_date(element, format))


def parse_date_to_time(date_object):
    return time.mktime(date_object.timetuple())


def parse_string_to_date(element, format):
    return datetime.datetime.strptime(element, format)


def parse_timestamp_to_date(timestamp):
    """ Change timestamp to date object

    :param timestamp: the time in POSIX timestamp
    :type timestamp: float

    :returns: the time as a date
    :rtype: date """
    return datetime.datetime.fromtimestamp(timestamp)


def parse_date_to_string(date_object, format):
    return datetime.datetime.strftime(date_object, format)


def parse_string_time_to_minutes(element):
    [hours, minutes, seconds] = element.split(':')

    minutes = int(minutes)

    if int(seconds) > 30:
        minutes += 1

    minutes += int(hours) * 60

    return minutes

def parse_string_to_string(element, format, new_format):
    if element != '':
        return parse_date_to_string(parse_string_to_date(element, format), new_format)
    else:
        return ''



import os
import time
from imghdr import what
import shutil
import requests
from firstimpression.scala import install_content
from firstimpression.api.request import request_json
from firstimpression.constants import TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, PLACEHOLDER_FOLDER, IMG_EXTENSIONS
import xml.etree.ElementTree as ET


def create_directories(directories):
    for dirpath in directories:
        if not os.path.exists(dirpath):
            os.makedirs(dirpath)


def get_age(filepath):
    return time.time() - os.path.getmtime(filepath)


def check_too_old(filepath, max_age):
    try:
        file_age = get_age(filepath)
    except WindowsError:
        return True

    if file_age > max_age:
        return True
    else:
        return False


def check_valid_jpeg(filepath):
    return what(filepath) == 'jpeg' or what(filepath) == 'jpg'


def download_media(media_link, subdirectory, temp_folder, filename=None):
    # Downloads and returns path of media
    if filename is None:
        media_filename = media_link.split('/').pop()
    else:
        media_filename = filename
    media_path = os.path.join(temp_folder, subdirectory, media_filename)

    response = requests.get(media_link, stream=True)

    with open(media_path, 'wb') as writefile:
        shutil.copyfileobj(response.raw, writefile)

    return media_path


def install_media(media_link, subdirectory):
    install_content(media_link, subdirectory)
    return os.path.join('Content:\\', subdirectory, media_link.split('\\').pop())


def purge_directories(directories, max_days):
    # Remove all files from directory that are older than max_days
    for directory in directories:
        for file in os.listdir(directory):
            
            filepath = os.path.join(directory, file)
            
            if os.path.isdir(filepath):
                purge_directories([filepath], max_days)
            else:
                file_age = get_age(filepath)

                if file_age > max_days * 86400:
                    os.remove(filepath)


def write_root_to_xml_files(root, path, subfolder=None):
    tree = ET.ElementTree(root)
    tree.write(path)
    install_content(path, subfolder)


def xml_to_root(path):
    tree = ET.parse(path)
    root = tree.getroot()
    return root

def list_files(url, extensions):
    response = request_json(url)
    all_elements = response.get('data', [])
    select_elements = [elem for elem in all_elements if '.' + elem.split('.')[-1] in extensions]
    return select_elements

def list_files_dir(path):
    return [file for file in os.listdir(path) if os.path.isfile(os.path.join(path, file))]

def update_directories_api(api_name, max_days=1):
    temp_folder = os.path.join(TEMP_FOLDER, api_name)
    local_folder = os.path.join(LOCAL_INTEGRATED_FOLDER, api_name)
    temp_placeholder = os.path.join(TEMP_FOLDER, 'placeholders')

    create_directories([temp_folder, local_folder, PLACEHOLDER_FOLDER, temp_placeholder])
    update_placeholders()
    purge_directories([temp_folder, local_folder], max_days)

def update_placeholders():
    url = 'https://fi-api.io/placeholder_images'
    max_age = 60 * 60 * 24

    for link in list_files(url, IMG_EXTENSIONS):
        file_name = link.split('/')[-1]
        if check_too_old(os.path.join(TEMP_FOLDER, 'placeholders', file_name), max_age):
            download_install_media(link, TEMP_FOLDER, 'placeholders')
            
def download_install_media(url, temp_dir, subdir, fname=None):
    return install_media(download_media(url, subdir, temp_dir, fname), subdir)


from firstimpression.api.request import request
import xml.etree.ElementTree as ET


def get_xml(url):
    response = request(url)
    return ET.fromstring(response.content)


def get_text_from_element(element, tag_name):
    return element.find(tag_name).text


def get_items_from_element(element, tag_name):
    return element.findall(tag_name)


def get_attrib_from_element(element, tag_name, attrib_name):
    return element.find(tag_name).attrib[attrib_name]



import xml.etree.ElementTree as ET
import os
import glob

from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER
from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files
from firstimpression.xml import get_xml
from firstimpression.scala import variables, Log

##################################################################################################
# LOGGING
##################################################################################################

script = 'Google Trends'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['trends']

XML_FILE_NAME = 'trends.xml'
XML_FILE_NAME_CONTENT = 'trends*.xml'
XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, XML_FILE_NAME)
XML_LOCAL_PATH = os.path.join(
    LOCAL_INTEGRATED_FOLDER, NAME, XML_FILE_NAME_CONTENT)

URL = 'https://trends.google.nl/trends/hottrends/atom/feed?pn=p17'

NAMESPACE = {
    'atom': 'http://www.w3.org/2005/Atom',
    'ht': 'https://trends.google.nl/trends/trendingsearches/daily'
}

TAGS = {
    'item': 'channel/item',
    'title': 'title',
    'traffic': 'ht:approx_traffic',
    'url': 'link'
}

MAX_FILE_AGE = 60 * 30


##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api():

    debug.log('folder name: {}'.format(NAME))
    debug.log('file location temp: {} - local: {}'.format(XML_TEMP_PATH,
                                                          XML_LOCAL_PATH))

    update_directories_api(NAME)

    if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
        root = get_xml(URL)
        new_root = ET.Element("root")

        for elem in root.findall(TAGS['item']):
            item = ET.SubElement(new_root, "item")
            ET.SubElement(item, "title").text = get_title(elem)
            ET.SubElement(item, "traffic").text = str(get_traffic(elem))
            ET.SubElement(item, "url").text = get_url(elem)

        debug.log(new_root)

        write_root_to_xml_files(new_root, XML_TEMP_PATH, NAME)
    else:
        debug.log('File not old enough to update')


def check_api():
    svars = variables()

    file_path = glob.glob(XML_LOCAL_PATH)

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, MAX_FILE_AGE):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_title(elem):
    return elem.findtext(TAGS['title'], '')


def get_traffic(elem):
    return elem.findtext(TAGS['traffic'], '', NAMESPACE)


def get_url(elem):
    return elem.findtext(TAGS['url'], '')

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################



import xml.etree.ElementTree as ET
import glob
import os

from firstimpression.constants import APIS, LOCAL_INTEGRATED_FOLDER, TEMP_FOLDER, DUTCH_INDEX, ENGLISH_INDEX, PICTURE_FORMATS, TAGS_TO_REMOVE, REPLACE_DICT
from firstimpression.file import create_directories, update_directories_api, check_too_old, write_root_to_xml_files, download_media, list_files_dir, xml_to_root
from firstimpression.time import change_language, parse_string_to_string, parse_date_to_string, parse_string_to_date
from firstimpression.rss import get_feed
from firstimpression.xml import get_attrib_from_element
from firstimpression.scala import install_content, variables, Log
from firstimpression.text import replace_html_entities, remove_tags_from_string

##################################################################################################
# LOGGING
##################################################################################################

script = 'Nu_nl'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)


##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['nu']

DATETIME_FORMAT = "%a, %d %b %Y %H:%M:%S "
DATETIME_ABREVIATION_FORMAT = '%d %b %Y %H:%M'
DATETIME_FULL_FORMAT = '%d %B %Y %H:%M'

MAX_ITEMS = 10
MAX_FILE_AGE = 60 * 10

LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME)

BASE_URL = 'http://www.nu.nl/rss/'

TAGS = {
    'item': 'channel/item',
    'title': 'title',
    'descr': 'description',
    'pubDate': 'pubDate'
}

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(news_categories, minimal_items):
    debug.log('folder name: {}'.format(NAME))
    minimal_items = MAX_ITEMS if minimal_items > MAX_ITEMS else minimal_items

    debug.log('local path: {}'.format(LOCAL_PATH))
    debug.log('minimal_items: {}'.format(minimal_items))
    
    update_directories_api(NAME)

    for news_category in news_categories:
        if news_category == '' or news_category is None:
            warn.log('category is empty')
            continue

        category = news_category.lower()

        url = BASE_URL + category

        create_directories([os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, category), os.path.join(TEMP_FOLDER, NAME, category)])

        xml_temp_path = os.path.join(TEMP_FOLDER, NAME, '{}.xml'.format(category))

        debug.log('category: {} - url: {} - temp path: {}'.format(category, url, xml_temp_path))

        if check_too_old(xml_temp_path, MAX_FILE_AGE):
            root = ET.Element("root")

            feed = get_feed(url)

            for news_item in feed.findall(TAGS['item']):
                item = ET.SubElement(root, "item")
                ET.SubElement(item, "title").text = replace_html_entities(REPLACE_DICT, get_title(news_item))
                ET.SubElement(item, "descr").text = remove_tags_from_string(TAGS_TO_REMOVE, get_description(news_item))
                ET.SubElement(item, "pubDate").text = parse_date_to_string(get_publication_date(news_item), DATETIME_ABREVIATION_FORMAT)
                ET.SubElement(item, "fullMonthPubDate").text = parse_date_to_string(get_publication_date(news_item), DATETIME_FULL_FORMAT)

                media_link_full = install_picture_content_wrap('fullscreen', os.path.join(NAME, category), TEMP_FOLDER, news_item, 'enclosure', 'url')
                media_link_sqr = install_picture_content_wrap('square', os.path.join(NAME, category), TEMP_FOLDER, news_item, 'enclosure', 'url')

                if media_link_full is None and media_link_sqr is None:
                    debug.log('No image found using placeholder instead')
                    media_link_full = media_link_sqr = 'Content:\\placeholders\\img.png'
                elif media_link_sqr is None:
                    media_link_sqr = media_link_full
                elif media_link_full is None:
                    media_link_full = media_link_sqr
                
                ET.SubElement(item, "picorg").text = media_link_full
                ET.SubElement(item, "picsqr").text = media_link_sqr

                if len(root) == MAX_ITEMS:
                    debug.log('max amount of items reached')
                    break

            if len(root) >= minimal_items:
                write_root_to_xml_files(root, xml_temp_path, NAME)
            else:
                warn.log('not enough news items to store to xml file')
        else:
            debug.log('File not old enough to update')

def check_api(news_categories):
    svars = variables()

    count_categories = 0

    for elem in news_categories:
        if elem != '':
            count_categories += 1

    svars['total_categories'] = count_categories

    files = list_files_dir(LOCAL_PATH)

    if len(files) > 0:
        file_found = False
        for file in files:
            debug.log('file: {}'.format(file))
            if 'xml' in file:
                file_found = True
                file_path = os.path.join(LOCAL_PATH, file)
                debug.log('file path: {}'.format(file_path))
                if check_too_old(file_path, MAX_FILE_AGE):
                    svars['skipscript'] = True
                    info.log('file too old')
                    break
                else:
                    svars['skipscript'] = False

                    amount_items = len(xml_to_root(file_path))

                    if amount_items == 0:
                        svars['skipscript'] = True
                        warn.log('file has no news items')
                        break
                    
                    svars['total_items'] = amount_items
        
        if not file_found:
            svars['skipscript'] = True
    else:
        svars['skipscript'] = True


##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################

def install_picture_content_wrap(picture_format, subdirectory, temp_folder, element, tag, attrib):
    # Installs content to LocalIntegratedContent folder and returns mediapath
    if not picture_format in PICTURE_FORMATS:
        warn.log('picture format is not in PICTURE_FORMATS')
        return None

    media_link = get_attrib_from_element(element, tag, attrib).replace("_sqr256", "")

    if picture_format == 'square':
        media_link = media_link.replace('.jpg', '_sqr512.jpg')

    media_path = download_media(PICTURE_FORMATS[picture_format] + media_link, subdirectory, temp_folder)

    install_content(media_path, subdirectory)

    media_filename = media_path.split('\\').pop()

    return os.path.join('Content:\\', subdirectory, media_filename)

##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_title(news_item):
    return news_item.findtext(TAGS['title'], '')

def get_description(news_item):
    return news_item.findtext(TAGS['descr'], '')

def get_publication_date(news_item):
    time = news_item.findtext(TAGS['pubDate'], None)
    change_language(ENGLISH_INDEX)
    if time is None:
        return ''
    else:
        date = parse_string_to_date(time[:-5], DATETIME_FORMAT)
        change_language(DUTCH_INDEX)
        return date

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################





import xml.etree.ElementTree as ET
import glob
import os

from geopy import distance

from firstimpression.constants import APIS, LOCAL_INTEGRATED_FOLDER, TEMP_FOLDER
from firstimpression.file import update_directories_api, write_root_to_xml_files, check_too_old, xml_to_root
from firstimpression.json import lst_dict_to_root
from firstimpression.scala import variables, Log
from firstimpression.api.request import request_json

##################################################################################################
# LOGGING
##################################################################################################

script = 'Traffic'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)


##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['traffic']

EXCLUDE_FROM_XML = 'coordinates'

XML_FILE_NAME_LONGEST = 'longest_jams.xml'
XML_TEMP_PATH_LONGEST = os.path.join(TEMP_FOLDER, NAME, XML_FILE_NAME_LONGEST)
XML_FILE_NAME_CLOSEST = 'closest_jams.xml'
XML_TEMP_PATH_CLOSEST = os.path.join(TEMP_FOLDER, NAME, XML_FILE_NAME_CLOSEST)

XML_LOCAL_LONGEST = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'longest_jams*.xml')
XML_LOCAL_CLOSEST = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'closest_jams*.xml')

MAX_FILE_AGE = 60 * 10

URL = 'https://api.rwsverkeersinfo.nl/api/traffic'

PARAMS = {
    'query_type': 'overview'
}

HEADERS = {
    'cache-control':'no-cache',
    'Accept': 'application/json'
}

TAGS = {
    'circumstances': 'obstructions'
}

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(jam_type, max_closest, max_longest, own_coordinates, only_highways):
    debug.log('folder name: {}'.format(NAME))
    debug.log('file paths - temp long: {} - local long: {} - temp close: {} - local close: {}'.format(XML_TEMP_PATH_LONGEST, XML_LOCAL_LONGEST, XML_TEMP_PATH_CLOSEST, XML_LOCAL_CLOSEST))
    debug.log('max_close: {} - max_long: {}'.format(max_closest, max_longest))

    update_directories_api(NAME)

    if (check_too_old(XML_TEMP_PATH_LONGEST, MAX_FILE_AGE) and max_longest > 0) or (check_too_old(XML_TEMP_PATH_CLOSEST, MAX_FILE_AGE) and max_closest > 0):
        traffic_info = request_json(URL, HEADERS, PARAMS)

        circumstances = parse_circumstances(get_circumstances(traffic_info), own_coordinates, only_highways)
        jams = get_jams(circumstances, jam_type)

        if check_too_old(XML_TEMP_PATH_LONGEST, MAX_FILE_AGE) and max_longest > 0:
            sorted_jams = sort_longest_jams(jams)
            sorted_jams = [{key: value for key, value in d.items() if key != EXCLUDE_FROM_XML} for d in sorted_jams]
            root = lst_dict_to_root(sorted_jams[:max_longest])

            ET.SubElement(root, "total_circumstances").text = str(get_total_jams(jams))
            ET.SubElement(root, "total_circumstances_string").text = get_total_jams_str(jams)
            ET.SubElement(root, "total_length").text = str(get_total_jam_length(traffic_info))
            ET.SubElement(root, "total_length_string").text = get_total_length_string(traffic_info)
            ET.SubElement(root, "total_delay_string").text = calculate_total_delay_str(jams)

            write_root_to_xml_files(root, XML_TEMP_PATH_LONGEST, NAME)
        else:
            debug.log('Longest xml does not need to be updated')

        if check_too_old(XML_TEMP_PATH_CLOSEST, MAX_FILE_AGE) and max_closest > 0:
            sorted_jams = sort_closest_jams(jams)
            sorted_jams = [{key: value for key, value in d.items() if key != EXCLUDE_FROM_XML} for d in sorted_jams]
            root = lst_dict_to_root(sorted_jams[:max_closest])

            ET.SubElement(root, "total_circumstances").text = str(get_total_jams(jams))
            ET.SubElement(root, "total_circumstances_string").text = get_total_jams_str(jams)
            ET.SubElement(root, "total_length").text = str(get_total_jam_length(traffic_info))
            ET.SubElement(root, "total_length_string").text = get_total_length_string(traffic_info)
            ET.SubElement(root, "total_delay_string").text = calculate_total_delay_str(jams)

            write_root_to_xml_files(root, XML_TEMP_PATH_CLOSEST, NAME)
        else:
            debug.log('Closest xml does not need to be updated')
    else:
        debug.log('Files are not updated')

def check_api():
    svars = variables()
    skip = False

    file_exists = [True, True]

    file_path_longest = glob.glob(XML_LOCAL_LONGEST)
    file_path_closest = glob.glob(XML_LOCAL_CLOSEST)

    if len(file_path_longest) > 0:
        file_path_longest = file_path_longest[0]
        debug.log('glob filepath: {}'.format(file_path_longest))

        if check_too_old(file_path_longest, MAX_FILE_AGE):
            skip = True
            info.log('file {} too old'.format(file_path_longest))
        else:
            if xml_to_root(file_path_longest).findtext('total_circumstances', 0) == 0:
                skip == True
                info.log('no traffic jams at the moment')
    else:
        warn.log('File {} in {} does not exists'.format(XML_LOCAL_LONGEST, file_path_longest))

        file_exists[0] = False

    if len(file_path_closest) > 0:
        file_path_closest = file_path_closest[0]
        debug.log('glob filepath: {}'.format(file_path_closest))

        if check_too_old(file_path_closest, MAX_FILE_AGE):
            skip = True
            info.log('file {} too old'.format(file_path_closest))
        else:
            if xml_to_root(file_path_closest).findtext('total_circumstances', 0) == 0:
                skip == True
                info.log('no traffic jams at the moment')
    else:
        warn.log('File {} in {} does not exists'.format(XML_LOCAL_CLOSEST, file_path_closest))

        file_exists[1] = False
    
    if skip == False:
        if not any(file_exists):
            skip = True

    svars['skipscript'] = skip

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_circumstances(traffic_info):
    return traffic_info.get(TAGS['circumstances'], {})


def get_reason(circumstance):
    return circumstance.get('cause', '')


def get_area_detail(circumstance):
    return circumstance.get('locationText', '')


def get_event(circumstance):
    return circumstance.get('title', '')


def get_description(circumstance):
    return circumstance.get('description', '')


def get_type(circumstance):
    return circumstance.get('obstructionType', 0)

def get_direction_text(circumstance):
    return circumstance.get('directionText', None)


def get_from(circumstance):
    text = get_direction_text(circumstance)
    if text is None:
        return ''
    else:
        return text.split(' - ')[0]


def get_to(circumstance):
    text = get_direction_text(circumstance)
    if text is None:
        return ''
    else:
        return text.split(' - ')[1]

def get_total_jams(jams):
    return len(jams)

def get_total_jams_str(jams):
    total = get_total_jams(jams)

    temp = '{} file'.format(total)

    if total != 1:
        temp += 's'
    
    return temp

def get_road_type(circumstance):
    road = get_road(circumstance)

    if road is None:
        return ''
    else:
        return road[0]


def get_road(circumstance):
    return circumstance.get('roadNumber', None)


def get_road_number(circumstance):
    road = get_road(circumstance)

    if road is None:
        return ''
    else:
        return road[1:]


def get_length(circumstance):
    total_length = circumstance.get('total_length', None)
    if total_length is None:
        return ''
    else:
        return int(total_length)


def get_length_string(circumstance):
    length = get_length(circumstance)
    if length != '':
        return '{} km'.format(length/1000)
    else:
        return 'onbekend'

def get_delay(circumstance):
    total_length = circumstance.get('delay', None)

    if total_length is None:
        return ''
    else:
        return int(total_length)

def get_delay_string(circumstance):
    delay = get_delay(circumstance)

    if delay is None:
        return ''
    else:
        return '+{} min'.format(delay)

def get_jams(circumstances, jam_type):
    jams = list()
    for circumstance in circumstances:
        if circumstance.get('type', 1) == jam_type:
            jams.append(circumstance)
    return jams

def get_longitude(circumstance):
    return circumstance.get('longitude', '')

def get_latitude(circumstance):
    return circumstance.get('latitude', '')

def get_coordinates(circumstance):
    return {'longitude': get_longitude(circumstance), 'latitude': get_latitude(circumstance)}


def get_total_jam_length(traffic_info):
    return traffic_info.get('totalLengthOfJams', 0) / 1000


def get_total_length_string(traffic_info):
    return '{} km'.format(get_total_jam_length(traffic_info))

def get_only_highways(parsed_circumstances):
    specific_circumstances = list()
    for circumstance in parsed_circumstances:
        if circumstance['road_type'] == 'A':
            specific_circumstances.append(circumstance)
    return specific_circumstances


##################################################################################################
# PARSE FUNCTIONS
##################################################################################################


def parse_circumstances(circumstances, own_coordinates, only_highways):
    parsed_circumstances = list()
    for circumstance in circumstances:
        parsed_circumstances.append(
            parse_circumstance(circumstance, own_coordinates))

    if only_highways:
        return get_only_highways(parsed_circumstances)
    else:
        return parsed_circumstances


def parse_circumstance(circumstance, own_coordinates):
    # Parses JSON from API to own format. Junk data is removed.
    parsed_circumstance = dict()

    parsed_circumstance['road_type'] = get_road_type(circumstance)
    parsed_circumstance['road'] = get_road(circumstance)
    parsed_circumstance['road_number'] = get_road_number(circumstance)
    parsed_circumstance['from'] = get_from(circumstance)
    parsed_circumstance['to'] = get_to(circumstance)
    parsed_circumstance['length'] = get_length(circumstance)
    parsed_circumstance['length_string'] = ''
    parsed_circumstance['reason'] = get_reason(circumstance)
    parsed_circumstance['area_detail'] = get_area_detail(circumstance)
    parsed_circumstance['event'] = get_event(circumstance)
    parsed_circumstance['description'] = get_description(circumstance)
    parsed_circumstance['type'] = get_type(circumstance)
    parsed_circumstance['total_delay'] = get_delay_string(circumstance)
    parsed_circumstance['coordinates'] = get_coordinates(circumstance)

    parsed_circumstance['distance_to_circumstance'] = calculate_distance_to_circumstance(
        own_coordinates, parsed_circumstance['coordinates'])

    return parsed_circumstance

def sort_longest_jams(jams):
    # Sorts longest jams starting with longest to shortest
    return sorted(jams, key=lambda i: i['length'], reverse=True)


def sort_closest_jams(jams):
    # Sorts jams that are closest to own location
    return sorted(jams, key=lambda i: i['distance_to_circumstance'])


def calculate_distance_to_circumstance(from_coordinates, to_coordinates):
    # Calculates distance from one coordinate to another (WATCH OUT: straight line, so no roads taken into account)
    if not from_coordinates or not to_coordinates:
        return ''

    coords_1 = (from_coordinates['latitude'], from_coordinates['longitude'])
    coords_2 = (to_coordinates['latitude'], to_coordinates['longitude'])

    return distance.distance(coords_1, coords_2).km


def calculate_total_delay_str(jams):
    total_delay = 0
    for jam in jams:
        delay = jam.get('total_delay', '')
        if delay == '':
            continue
        else:
            total_delay += int(delay.split(' ').pop(0))

    if total_delay > 60:
        return '{}+ uur'.format(int(total_delay / 60))
    else:
        return '{} min'.format(int(total_delay))



from tempfile import gettempdir
import os
import re
import mimetypes

mimetypes.init()

PICTURE_FORMATS = {
    'fullscreen': "http://narrowcasting.fimpweb.nl/imageresize.php?width=1920&url=",
    'square':     "http://narrowcasting.fimpweb.nl/imageresize.php?width=512&url=",
}

TEMP_FOLDER = gettempdir()
LOCAL_INTEGRATED_FOLDER_LIST = ['C:/Users/Public/Documents/Scala/LocalIntegratedContent', 'D:/SCALA/PLAYER_CFG_DATA/Documents/LocalIntegratedContent']

APIS = {
    'amber':'AMBER_ALERT',
    'schiphol':'AMS_AIRPORT',
    'bbc':'BBC',
    'ns':'NS',
    'traffic':'TRAFFIC',
    'insta':'INSTAGRAM',
    'weather':'WEATHER',
    'jokes':'CHUCK_NORRIS',
    'eindhoven':'EHV_AIRPORT',
    'facebook':'FACEBOOK',
    'trends':'GOOGLE_TRENDS',
    'news_polish':'INTERIA',
    'concerts':'SONGKICK',
    'nu': 'NU',
    'solaredge': 'SOLAREDGE',
    'countdown': 'COUNTDOWN',
    'twitter': 'TWITTER'
}

VIDEO_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'video']
IMG_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'image']

ENGLISH_INDEX = 0
DUTCH_INDEX = 1

TAGS_TO_REMOVE = re.compile(r'<[^>]+>')
REPLACE_DICT = {
    "<em>": "<italic = \"On\">",
    "</em>": "<italic = \"Off\">",
    "<b>": "<bold = \"On\">",
    "</b>": "<bold = \"Off\">",
    u'\xa0': ""
}

CRITICAL = 50
FATAL = CRITICAL
ERROR = 40
WARNING = 30
WARN = WARNING
INFO = 20
DEBUG = 10
NOTSET = 0

LEVELNAME = {
    CRITICAL: 'CRITICAL',
    ERROR: 'ERROR',
    WARNING: 'WARNING',
    INFO: 'INFO',
    DEBUG: 'DEBUG',
    NOTSET: 'NOTSET',
}
NAMELEVEL = {
    'CRITICAL': CRITICAL,
    'FATAL': FATAL,
    'ERROR': ERROR,
    'WARN': WARNING,
    'WARNING': WARNING,
    'INFO': INFO,
    'DEBUG': DEBUG,
    'NOTSET': NOTSET,
}

SAMSUNG_MONITOR_ON_MESSAGE = b'\xAA\x11\xFE\x01\x01\x11'
SAMSUNG_MONITOR_OFF_MESSAGE = b'\xAA\x11\xFE\x01\x00\x10'
SAMSUNG_MONITOR_SWITCH_PORT = 1515


from firstimpression.scala import variables

svars = variables()

if svars['Player.local_integrated_folder_on_d']:
    LOCAL_INTEGRATED_FOLDER = LOCAL_INTEGRATED_FOLDER_LIST[1]
else:
    LOCAL_INTEGRATED_FOLDER = LOCAL_INTEGRATED_FOLDER_LIST[0]

PLACEHOLDER_FOLDER = os.path.join(LOCAL_INTEGRATED_FOLDER, 'placeholders')


import os
import json
import datetime
import glob
import xml.etree.ElementTree as ET

from firstimpression.constants import TEMP_FOLDER, APIS, LOCAL_INTEGRATED_FOLDER
from firstimpression.file import download_install_media, write_root_to_xml_files, update_directories_api, check_too_old
from firstimpression.time import parse_date_to_string, parse_string_to_string
from firstimpression.json import lst_dict_to_root
from firstimpression.scala import variables, Log
from firstimpression.api.request import request


##################################################################################################
# LOGGING
##################################################################################################

script = 'Schiphol'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['schiphol']

URL_FLIGHTS = 'https://api.schiphol.nl/public-flights/flights'
URL_STATIONS = 'https://api.schiphol.nl/public-flights/destinations'

STATIONS_JSON_FILENAME = 'stations.json'
STATIONS_MAX_FILE_AGE = 60 * 60 * 24 * 7 * 4

FLIGHTS_XML_FILENAME = 'flights.xml'
FLIGHTS_XML_FILENAME_CONTENT = 'flights*.xml'
FLIGHTS_MAX_FILE_AGE = 60 * 10

PURGE_DIRECTORIES_DAYS = 7 * 4

XML_TEMP_PATH_FLIGHTS = os.path.join(TEMP_FOLDER, NAME, FLIGHTS_XML_FILENAME)
XML_LOCAL_PATH_FLIGHTS = os.path.join(
    LOCAL_INTEGRATED_FOLDER, NAME, FLIGHTS_XML_FILENAME_CONTENT)
JSON_PATH_STATIONS = os.path.join(
    LOCAL_INTEGRATED_FOLDER, NAME, STATIONS_JSON_FILENAME)

FLIGHTS_MAX = 10

DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
DATE_FORMAT = '%Y-%m-%d'
SCHEDULE_DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S.000'
TIME_FORMAT = '%H:%M'

RESOURCE_VERSION = 'v4'

DEPARTING_STATUS = {
    'SCH': 'Flight scheduled',
    'DEL': 'Delayed',
    'WIL': 'Wait in Lounge',
    'GTO': 'Gate Open',
    'BRD': 'Boarding',
    'GCL': 'Gate Closing',
    'GTD': 'Gate closed',
    'DEP': 'Departed',
    'CNX': 'Cancelled',
    'GCH': 'Gate Change',
    'TOM': 'Tomorrow'
}

HEADERS = {
    'Accept': 'application/json',
    'ResourceVersion': RESOURCE_VERSION
}

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################


def run_api(id, key):
    debug.log('folder name: {}'.format(NAME))
    debug.log('file paths: temp -> {}, local -> {}, local station -> {}'.format(
        XML_TEMP_PATH_FLIGHTS, XML_LOCAL_PATH_FLIGHTS, JSON_PATH_STATIONS))

    HEADERS['app_id'] = id
    HEADERS['app_key'] = key

    debug.log('app_id: {} - app_key: {}'.format(id, key))

    update_directories_api(NAME, PURGE_DIRECTORIES_DAYS)

    if check_too_old(JSON_PATH_STATIONS, STATIONS_MAX_FILE_AGE):
        page = 0
        params = dict()
        stations = dict()

        for i in range(100000):
            params['page'] = page
            response = request(URL_STATIONS, HEADERS, params)

            if response.status_code != 200:
                debug.log('No more pages found for stations')
                break

            stations.update(get_stations(response.json()))

            page += 1

        debug.log('page of stations: {}'.format(page))

        if page == 99999:
            warn.log('Something went probably wrong when downloading stations')

        with open(JSON_PATH_STATIONS, 'w') as file:
            json.dump(stations, file)
    else:
        debug.log('Station file not old enough')

    if check_too_old(XML_TEMP_PATH_FLIGHTS, FLIGHTS_MAX_FILE_AGE):
        page = 0
        params = {
            'sort': '+scheduleDateTime',
            'flightDirection': 'D',
            'searchDateTimeField': 'scheduleDateTime',
            'fromDateTime': parse_date_to_string(datetime.datetime.now(), DATETIME_FORMAT),
            'toDateTime': parse_date_to_string(datetime.datetime.now(), DATE_FORMAT) + 'T23:59:59'
        }
        flights = list()

        debug.log(params)

        if os.path.isfile(JSON_PATH_STATIONS):
            destinations = json.load(open(JSON_PATH_STATIONS, 'r'))
        else:
            error.log('The stations file does not exists.')
            raise FileExistsError(
                "The stations file does not exists. Run this first.")

        for i in range(100000):
            params['page'] = page
            response = request(URL_FLIGHTS, HEADERS, params)

            if response.status_code != 200:
                debug.log('No more flights found.')
                break

            flights = parse_flights(flights, destinations, response.json())

            if len(flights) == FLIGHTS_MAX:
                debug.log('Max amount of flights')
                break

            page += 1

        debug.log('page of flights: {}'.format(page))
        debug.log(flights)

        if len(flights) == 0:
            warn.log('No flights saved')

        if page == 99999:
            warn.log('Something went probably wrong when downloading flights')

        write_root_to_xml_files(lst_dict_to_root(
            flights), XML_TEMP_PATH_FLIGHTS, NAME)
    else:
        debug.log('File not old enough flights')


def check_api():
    svars = variables()
    file_path = glob.glob(XML_LOCAL_PATH_FLIGHTS)

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, FLIGHTS_MAX_FILE_AGE):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_stations(response):
    stations = dict()
    for destination in response.get('destinations', []):
        if not destination.get('iata', 'null') == 'null' and not destination.get('iata', None) is None:
            name = destination.get('publicName', None)
            if not name is None:
                full_name = name.get('english', None)
                if not full_name is None:
                    stations[destination['iata']] = full_name

    if len(stations) == 0:
        error.log('No stations saved')
        raise Exception('Schiphol: No stations saved')

    return stations


def get_flight_route(flight, destinations):

    route = list()

    for elem in flight.get('route', {}).get('destinations', 'null'):
        location = destinations.get(elem, 'Onbekend')
        if location == 'Onbekend':
            debug.log('location route: {}'.format(elem))
        route.append(location)

    return ', '.join(route)


def get_departure_time(flight):
    dt = flight.get('scheduleDateTime', None)
    if dt is None:
        return ''
    else:
        dt = dt[:-6]
        return parse_string_to_string(dt, SCHEDULE_DATETIME_FORMAT, TIME_FORMAT)


def get_flight_number(flight):
    return flight.get('flightName', 'Onbekend')


def get_flight_status(flight):
    status = flight.get('publicFlightState', {}).get(
        'flightStates', ['null'])[0]

    return DEPARTING_STATUS.get(status, 'Unknown')

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################


def parse_flights(flights, destinations, response):

    for flight_info in response.get('flights', []):
        flight = dict()
        skip = False

        flight['route'] = get_flight_route(flight_info, destinations)
        flight['departure_time'] = get_departure_time(flight_info)
        flight['flight_number'] = get_flight_number(flight_info)
        flight['status'] = get_flight_status(flight_info)

        for i in range(len(flights)):
            if flights[i]['route'] == flight['route'] and flights[i]['departure_time'] == flight['departure_time'] and flights[i]['status'] == flight['status']:
                flights[i]['flight_number'] += ', ' + flight['flight_number']
                skip = True
                debug.log('flight {} is same as flight {}'.format(
                    flight['flight_number'], flights[i]['flight_number']))

        if not skip:
            flights.append(flight)

        if len(flights) == FLIGHTS_MAX:
            debug.log('break because max amount of fligths reached')
            break

    return flights



from firstimpression import api
from firstimpression import file
from firstimpression import rss
from firstimpression import scala
from firstimpression import text
from firstimpression import time
from firstimpression import xml
from firstimpression import json
from firstimpression import constants
from firstimpression import local


import os
import glob
import xml.etree.ElementTree as ET

from firstimpression.constants import TEMP_FOLDER, APIS, LOCAL_INTEGRATED_FOLDER, NAMELEVEL
from firstimpression.file import download_install_media, update_directories_api, check_too_old, write_root_to_xml_files, xml_to_root
from firstimpression.xml import get_xml
from firstimpression.scala import Log, variables


##################################################################################################
# LOGGING
##################################################################################################

script = 'Amber Alert'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['amber']

XML_FILENAME = 'amber_alert.xml'
XML_FILENAME_CONTENT = 'amber_alert*.xml'

URL = 'https://media.amberalert.nl/xml/combined/index.xml'

XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
XML_LOCAL_PATH = os.path.join(
    LOCAL_INTEGRATED_FOLDER,
    NAME,
    XML_FILENAME_CONTENT
)

URL_LOGO = 'http://fimp.nl/narrowcasting/amberalert.png'

MAX_FILE_AGE = 60 * 10

NAMESPACE_XML = {
    'NP': 'http://www.netpresenter.com'
}

TAGS = {
    'alert': 'NP:Alert',
    'soort': 'NP:AlertLevel',
    'status': 'NP:Status',
    'type': 'NP:Type',
    'message': 'NP:Message/NP:Common/NP:ISource',
    'name': 'NP:Title',
    'description': 'NP:Description',
    'readmore': 'NP:Readmore_URL',
    'amberlink': 'NP:Media_URL',
    'image': 'NP:Media/NP:Image'
}

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################


def run_api():
    debug.log('folder name: {}'.format(NAME))
    debug.log(
        'File locations: temp -> {} & local -> {}'.format(XML_TEMP_PATH, XML_LOCAL_PATH))
    update_directories_api(NAME)

    if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
        root = get_xml(URL)
        new_root = ET.Element("root")
        counter = 0

        download_install_logo()

        for alert in get_alerts(root):
            counter += 1
            new_root.append(parse_alert(alert))

        ET.SubElement(new_root, "alerts").text = str(counter)

        if counter == 0:
            info.log('No alerts to show')

        debug.log(new_root)

        write_root_to_xml_files(new_root, XML_TEMP_PATH, NAME)

    else:
        debug.log('File not old enough to update')


def check_api():
    svars = variables()
    file_path = glob.glob(XML_LOCAL_PATH)

    if len(file_path > 0):
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, MAX_FILE_AGE):
            svars['skipscript'] = True
            debug.log('file too old')
        else:
            svars['skipscript'] = False

            amount_items = int(xml_to_root(file_path).get('alerts', '0'))

            svars['total_items'] = amount_items

            if amount_items == 0:
                svars['skipscript'] = True
                info.log('No alerts to show')
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


def download_install_logo():
    download_install_media(URL_LOGO, TEMP_FOLDER, NAME)


def download_photo_child(url):
    return download_install_media(url, TEMP_FOLDER, NAME)

##################################################################################################
# GET FUNCTIONS
##################################################################################################


def get_alerts(root):
    return root.findall(TAGS['alert'], NAMESPACE_XML)


def get_alert_soort(alert):
    if alert.findtext(TAGS['soort'], '0', NAMESPACE_XML) == '10':
        return 'Amber Alert'
    else:
        return 'Vermist kind'


def get_alert_status(alert):
    return alert.findtext(TAGS['status'], 'Onbekend', NAMESPACE_XML)


def get_alert_type(alert):
    return alert.findtext(TAGS['type'], 'Onbekend', NAMESPACE_XML)


def get_alert_message(alert):
    return alert.find(TAGS['message'], NAMESPACE_XML)


def get_name_child(message):
    return message.findtext(TAGS['name'], 'Onbekend', NAMESPACE_XML)


def get_message_description(message):
    return message.findtext(TAGS['description'], '', NAMESPACE_XML)


def get_more_info_url(message):
    return message.findtext(TAGS['readmore'], '', NAMESPACE_XML)


def get_amber_url(message):
    return message.findtext(TAGS['amberlink'], '', NAMESPACE_XML)


def get_photo_child(message):
    media_url = message.findtext(TAGS['image'], None, NAMESPACE_XML)

    if media_url is None:
        return 'Content:\\placeholders\\img.png'
    else:
        return download_photo_child(media_url)

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################


def parse_alert(alert):
    item = ET.Element("item")
    ET.SubElement(item, "soort").text = get_alert_soort(alert)
    ET.SubElement(item, "status").text = get_alert_status(alert)
    ET.SubElement(item, "type").text = get_alert_type(alert)

    message = get_alert_message(alert)

    ET.SubElement(item, "naam").text = get_name_child(message)
    ET.SubElement(item, "description").text = get_message_description(message)
    ET.SubElement(item, "readmore").text = get_more_info_url(message)
    ET.SubElement(item, "amberlink").text = get_amber_url(message)
    ET.SubElement(item, "image").text = get_photo_child(message)

    return item


import json
import glob
import os

from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER
from firstimpression.file import update_directories_api, write_root_to_xml_files, check_too_old
from firstimpression.time import parse_string_to_date, parse_string_time_to_minutes, parse_date_to_string, parse_string_to_string
from firstimpression.json import lst_dict_to_root
from firstimpression.scala import variables, Log
from firstimpression.api.request import request_json

##################################################################################################
# LOGGING
##################################################################################################

script = 'NS'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['ns']

LANGUAGE = 'nl'

DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'

URL_STATIONS = 'https://gateway.apiportal.ns.nl/reisinformatie-api/api/v2/stations'
URL_DEPARTURES = 'https://gateway.apiportal.ns.nl/reisinformatie-api/api/v2/departures'

MAX_FILE_AGE_DEPARTURES = 60 * 3
MAX_FILE_AGE_STATIONS = 60 * 60 * 24 * 60

STATIONS_JSON_FILENAME = 'stations.json'
STATIONS_JSON_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, STATIONS_JSON_FILENAME)


##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(api_key, station, max_journeys):
    
    debug.log('folder name: {}'.format(NAME))

    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, 'departures_{}.xml'.format(station))
    
    debug.log('temp path: {}'.format(xml_temp_path))

    params = {
        'maxJourneys': str(max_journeys),
        'lang': LANGUAGE,
        'station': station
    }

    headers = {
        'Ocp-Apim-Subscription-Key': api_key
    }

    update_directories_api(NAME)

    if check_too_old(STATIONS_JSON_PATH, MAX_FILE_AGE_STATIONS):
        with open(STATIONS_JSON_PATH, 'w') as file:
            json.dump(request_json(URL_STATIONS, headers), file)
    else:
        debug.log('Stations JSON not old enough to update')

    if check_too_old(xml_temp_path, MAX_FILE_AGE_DEPARTURES):
        write_root_to_xml_files(lst_dict_to_root(get_parsed_departures(get_response(URL_DEPARTURES, headers, params), DATETIME_FORMAT)), xml_temp_path, NAME)
    else:
        debug.log('Departures file is not old enough to update')

def check_api(station):
    stations = json.load(open(STATIONS_JSON_PATH, 'r'))
    svars = variables()

    debug.log('station: {}'.format(station))

    for stat in stations.get('payload', {}):
        if stat.get('code', None) == station:
            svars['station_name'] = stat.get('namen', {}).get('lang', 'Onbekend')
            break
    
    file_path = glob.glob(os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'departures_{}*.xml'.format(station)))
    
    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, MAX_FILE_AGE_DEPARTURES):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_response(url, headers, params):
    response_json = request_json(url, headers, params)

    if response_json.get('statusCode', None) == 429:
        error.log('Rate limit exceeded')
        raise Exception('Rate limit exceeded')

    return response_json


def get_departures(response_json):
    return response_json.get('payload',{}).get('departures', '')


def get_departure_time(departure):
    time = departure.get('plannedDateTime', None)
    if time is None:
        return ''
    else:
        return time[:-5]


def get_actual_departure_time(departure):
    time = departure.get('actualDateTime', None)
    if time is None:
        return ''
    else:
        return time[:-5]


def get_departure_number(departure):
    return departure.get('product', {}).get('number', '')


def get_destination(departure):
    return departure.get('direction', '')


def get_train_category(departure):
    return departure.get('product', {}).get('longCategoryName', '')


def get_route_text(departure):
    # Returns string with stations on route in this format: '{station}, {station}, {station}'
    return ', '.join([station.get('mediumName', 'station') for station in departure.get('routeStations', {})])


def get_operator(departure):
    return departure.get('product', {}).get('operatorName', '')


def get_planned_track(departure):
    if get_actual_track(departure) == '':
        return departure.get('plannedTrack', '')
    else:
        return get_actual_track(departure)


def get_actual_track(departure):
    return departure.get('actualTrack', '')


def get_delay(departure, date_format):
    try:
        if departure.get('cancelled', False) == True:
            return 'Rijdt niet'
    except KeyError:
        pass

    planned_departure_time = parse_string_to_date(get_departure_time(departure), date_format)
    actual_departure_time = parse_string_to_date(get_actual_departure_time(departure), date_format)

    if planned_departure_time < actual_departure_time:
        delayed_time = actual_departure_time - planned_departure_time
        delayed_minutes = parse_string_time_to_minutes(str(delayed_time))
        return ''.join(['+', str(delayed_minutes), ' min'])
    else:
        return ''


def get_message(departure):
    try:
        message = departure.get('messages', False)
        if message:
            msg = message[0].get('message', '')
        else:
            msg = ''
    except KeyError:
        msg = ''
    return msg

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################

def get_parsed_departures(response_json, date_format):
    departures = get_departures(response_json)
    parsed_departures = list()
    for departure in departures:
        parsed_departure = dict()
        parsed_departure['departure_number'] = get_departure_number(departure)
        parsed_departure['departure_time'] = parse_string_to_string(get_departure_time(departure), date_format, '%H:%M')
        parsed_departure['destination'] = get_destination(departure)
        parsed_departure['train_category'] = get_train_category(departure)
        parsed_departure['route_text'] = get_route_text(departure)
        parsed_departure['operator'] = get_operator(departure)
        parsed_departure['planned_track'] = get_planned_track(departure)
        parsed_departure['delay'] = get_delay(departure, date_format)
        parsed_departure['message'] = get_message(departure)
        parsed_departures.append(parsed_departure)

    return parsed_departures



import xml.etree.ElementTree as ET
import os
import glob
from firstimpression import file

from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, ENGLISH_INDEX, DUTCH_INDEX
from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files, download_install_media, list_files_dir, xml_to_root
from firstimpression.time import change_language, parse_string_to_string
from firstimpression.text import remove_emoji
from firstimpression.scala import variables, Log
from firstimpression.api.request import request_json

##################################################################################################
# LOGGING
##################################################################################################

script = 'Instagram'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['insta']

DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'

LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME)

URL = 'https://fi-api.io/instagram_post/'
BASE_URL_IMAGES = 'https://socials-bucket.s3.eu-central-1.amazonaws.com'

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(api_key, max_minutes, max_characters, max_items, language, tags):

    debug.log('folder name: {}'.format(NAME))
        
    max_file_age = 60 * max_minutes

    debug.log('max_file_age: {}'.format(max_file_age))

    if language == 'NL':
        info.log('change language to dutch')
        change_language(DUTCH_INDEX)
        datetime_format_new = '%d %B %Y'
        language_index = DUTCH_INDEX
    else:
        info.log('change language to english')
        change_language(ENGLISH_INDEX)
        datetime_format_new = '%B %d %Y'
        language_index = ENGLISH_INDEX

    headers = {
        'Authorization': 'Token {}'.format(api_key)
    }

    tags = tags.split(';')

    update_directories_api(NAME)

    params = {
        'number_of_posts': max_items
    }

    for tag in tags:
        root = ET.Element("root")
        if not (tag is None or tag == ''):
            params['tag'] = tag
            xml_temp_path = os.path.join(TEMP_FOLDER, NAME, 'instagram_{}.xml'.format(tag))
        else:
            params.pop('tag', None)
            xml_temp_path = os.path.join(TEMP_FOLDER, NAME, 'instagram.xml')
        
        debug.log('file path temp: {} - local: {}'.format(xml_temp_path, LOCAL_PATH))
        
        if check_too_old(xml_temp_path, max_file_age):

            response_json = request_json(URL, headers, params, False)

            for post in response_json:
                root.append(parse_post(post, max_characters, language_index, datetime_format_new))
    
            write_root_to_xml_files(root, xml_temp_path, NAME)
        else:
            debug.log('File not old enough')      
    
def check_api(max_minutes, tag, min_items):
    svars = variables()

    max_file_age = 60 * max_minutes

    debug.log('max_file_age: {}'.format(max_file_age))

    if tag is '' or tag is None:
        file_name = 'instagram[*.xml'
    else:
        file_name = 'instagram_{}*.xml'.format(tag)

    file_path = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, file_name)

    debug.log('local path: {}'.format(file_path))

    file_path = glob.glob(file_path)

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, max_file_age):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
            amount_items = len(xml_to_root(file_path))

            if amount_items < min_items:
                svars['skipscript'] = True
                info.log('{} has to less post to show'.format(tag))
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True


##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_media(post):
    return post.get('media', None)


def get_message(post):
    return post.get('message', '')


def get_creation_date(post):
    return post.get('created_at', '')[:19]

def get_likes(post):
    return post.get('likes', 0)


##################################################################################################
# PARSE FUNCTIONS
##################################################################################################

def crop_message(text, max_length, language):
    if language == 1:
        append_text = "Lees verder op Instagram"
    else:
        append_text = "Read more on Instagram"

    if len(text) > max_length:
        return text[:max_length-3] + "...\n{}".format(append_text)
    else:
        return text


def parse_post(post, max_characters, language_index, datetime_format_new):
    item = ET.Element("item")
    ET.SubElement(item, "likes").text = str(get_likes(post))
    ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters, language_index)
    ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, datetime_format_new)

    thumbnail_url = get_media(post)
    if thumbnail_url is None:
        debug.log('image not found so using placeholder')
        media_link = 'Content:\\placeholders\\img.png'
    else:
        media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
    
    ET.SubElement(item, "media").text = media_link

    if media_link.endswith("mp4"):
        ET.SubElement(item, "media_type").text = "video"
    else:
        ET.SubElement(item, "media_type").text = "image"
    
    return item




import xml.etree.ElementTree as ET
import os
import glob

from firstimpression.api.request import request_json
from firstimpression.constants import APIS, DUTCH_INDEX, LOCAL_INTEGRATED_FOLDER, TEMP_FOLDER
from firstimpression.file import check_too_old, download_install_media, update_directories_api, write_root_to_xml_files
from firstimpression.scala import variables, Log
from firstimpression.text import remove_emoji
from firstimpression.time import change_language, parse_string_to_string

##################################################################################################
# LOGGING
##################################################################################################

script = 'Twitter'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['twitter']

DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
DATETIME_FORMAT_NEW = '%d %B %Y'

URL = 'https://fi-api.io/twitter_post/'

XML_FILENAME = 'twitter.xml'
XML_FILENAME_CONTENT = 'twitter*.xml'
XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, XML_FILENAME_CONTENT)

MAX_FILE_AGE = 60 * 5

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(api_key, max_items):
    debug.log('folder name: {}'.format(NAME))
    debug.log('file path temp: {} - local: {}'.format(XML_TEMP_PATH, XML_LOCAL_PATH))

    headers = {
        'Authorization': 'Token {}'.format(api_key)
    }

    params = {
        'number_of_posts': max_items
    }

    update_directories_api(NAME)
    change_language(DUTCH_INDEX)

    if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
        response_json = request_json(URL, headers, params, False)

        root = ET.Element("root")

        for post in response_json:
            root.append(parse_post(post))
        
        write_root_to_xml_files(root, XML_TEMP_PATH, NAME)
    else:
        debug.log('File not old enough to update')

def check_api():
    svars = variables()

    file_path = glob.glob(XML_LOCAL_PATH)

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, MAX_FILE_AGE):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True


##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_likes(post):
    return post.get('likes', 0)

def get_message(post):
    return post.get('message', '')

def get_creation_date(post):
    return post.get('created_at', '')

def get_image(post):
    url = post.get('image', None)
    if url is None:
        debug.log('No image found using placeholder instead')
        return 'Content:\\placeholders\\img.png'
    else:
        return download_install_media(url, TEMP_FOLDER, NAME)


##################################################################################################
# PARSE FUNCTIONS
##################################################################################################

def parse_post(post):
    item = ET.Element("item")
    ET.SubElement(item, "likes").text = str(get_likes(post))
    ET.SubElement(item, "message").text = remove_emoji(get_message(post))
    ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, DATETIME_FORMAT_NEW)
    ET.SubElement(item, "image").text = get_image(post)
    return item


import xml.etree.ElementTree as ET


def lst_dict_to_root(json):
    root = ET.Element("root")

    for elem in json:
        item = ET.SubElement(root, 'item')
        for (key, value) in elem.items():
            ET.SubElement(item, key).text = str(value)
    
    return root





import xml.etree.ElementTree as ET
import os

from firstimpression.constants import APIS, TEMP_FOLDER, ENGLISH_INDEX, REPLACE_DICT, TAGS_TO_REMOVE, LOCAL_INTEGRATED_FOLDER
from firstimpression.file import update_directories_api, xml_to_root, check_too_old, write_root_to_xml_files, list_files_dir
from firstimpression.text import replace_html_entities, remove_tags_from_string
from firstimpression.rss import get_feed
from firstimpression.time import change_language, parse_string_to_string
from firstimpression.scala import variables, Log


##################################################################################################
# LOGGING
##################################################################################################

script = 'BBC'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['bbc']

LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME)

DATETIME_FORMAT = "%a, %d %b %Y %H:%M:%S GMT"
DATETIME_ABREVIATION_FORMAT = '%b %d %Y %H:%M'
DATETIME_FULL_FORMAT = '%B %d %Y %H:%M'

MAX_ITEMS = 10
MAX_FILE_AGE = 60 * 10

TAGS = {
    'item': 'channel/item',
    'title': 'title',
    'descr': 'description',
    'pubDate': 'pubDate'
}

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################


def run_api(news_category, minimal_items):
    debug.log('folder name: {}'.format(NAME))
    xml_temp_path = os.path.join(TEMP_FOLDER,
                                 NAME,
                                 '{}.xml'.format(news_category))
    
    debug.log('file path {}: {}'.format(news_category, xml_temp_path))

    url = 'http://feeds.bbci.co.uk/news/{}/rss.xml'.format(news_category)
    minimal_items = MAX_ITEMS if minimal_items > MAX_ITEMS else minimal_items

    debug.log('url: {}'.format(url))
    debug.log('minimal_items: {}'.format(minimal_items))

    update_directories_api(NAME)
    change_language(ENGLISH_INDEX)

    if check_too_old(xml_temp_path, MAX_FILE_AGE):
        root = ET.Element("root")
        feed = get_feed(url)

        for news_item in get_news_items(feed):
            root.append(parse_news_item(news_item))

            if len(root) == MAX_ITEMS:
                debug.log('max amount of items reached')
                break

        if len(root) >= minimal_items:
            write_root_to_xml_files(root, xml_temp_path, NAME)
        else:
            warn.log('root consist out of less than minimal items.')
    else:
        debug.log('file not old enough to update')


def check_api():
    svars = variables()

    for file in list_files_dir(LOCAL_PATH):
        debug.log('file: {}'.format(file))
        if 'xml' in file:
            file_path = os.path.join(LOCAL_PATH, file)
            debug.log('xml file: {}'.format(file_path))
            if check_too_old(file_path, MAX_FILE_AGE):
                svars['skipscript'] = True
                warn.log('file too old to show')
                break
            else:
                svars['skipscript'] = False

                amount_items = len(xml_to_root(file_path))

                if amount_items == 0:
                    warn.log('no items found in xml file')
                    svars['skipscript'] = True
                    break

                svars['total_items'] = amount_items

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_news_items(root):
    return root.findall(TAGS['item'])


def get_news_title(news_item):
    return replace_html_entities(REPLACE_DICT, news_item.findtext(TAGS['title'], ''))


def get_news_description(news_item):
    return remove_tags_from_string(TAGS_TO_REMOVE, news_item.findtext(TAGS['descr'], ''))


def get_short_date(news_item):
    return parse_string_to_string(news_item.findtext(TAGS['pubDate'], ''), DATETIME_FORMAT, DATETIME_ABREVIATION_FORMAT)


def get_full_date(news_item):
    return parse_string_to_string(news_item.findtext(TAGS['pubDate'], ''), DATETIME_FORMAT, DATETIME_FULL_FORMAT)

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################


def parse_news_item(news_item):
    item = ET.Element("item")
    ET.SubElement(item, "title").text = get_news_title(news_item)
    ET.SubElement(item, "descr").text = get_news_description(news_item)
    ET.SubElement(item, "pubDate").text = get_short_date(news_item)
    ET.SubElement(item, "fullMonthPubDate").text = get_full_date(news_item)

    debug.log('item: {}'.format(item))

    return item



import os
import glob
from firstimpression import file
import lxml.html
import xml.etree.ElementTree as ET

from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER
from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files
from firstimpression.scala import variables, Log
from firstimpression.api.request import request


##################################################################################################
# LOGGING
##################################################################################################

script = 'Eindhoven Airport'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['eindhoven']
URL = 'https://www.eindhovenairport.nl/nl/vertrektijden'

XML_FILENAME = 'flights.xml'
XML_FILENAME_CONTENT = 'flights*.xml'
XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, XML_FILENAME_CONTENT)
MAX_FILE_AGE = 60 * 10

TABLE_FLIGHTS_XPATH = '//div[@id="skyguide"]/div/table'

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api():

    debug.log('folder name: {}'.format(NAME))
    debug.log('temp path: {} - local path: {}'.format(XML_TEMP_PATH, XML_LOCAL_PATH))

    update_directories_api(NAME)

    if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
        root = ET.Element("root")

        response = lxml.html.fromstring(request(URL).text)

        table = response.xpath(TABLE_FLIGHTS_XPATH)[0]

        for row in table.xpath('tr'):
            item = ET.Element("item")
            store = False
            column_number = 1

            for column in row.xpath('td'):
                column_text = column.xpath('text()')

                if len(column_text) == 0:
                    column_text.append('')
                
                if column_number == 1:
                    ET.SubElement(item, "departure_time").text = column_text[0]
                elif column_number == 2:
                    ET.SubElement(item, "flight_number").text = column_text[0]
                elif column_number == 3:
                    ET.SubElement(item, "route").text = column_text[0]
                elif column_number == 4:
                    ET.SubElement(item, "status").text = column_text[0]
                    if not "Vertrokken" in column_text[0]:
                        debug.log('flight {} already left'.format(item.findtext('flight_number')))
                        store = True
                elif column_number == 5:
                    pass
                
                column_number += 1
            
            if store:
                root.append(item)
        
        write_root_to_xml_files(root, XML_TEMP_PATH, NAME)
    else:
        debug.log('File not old enough to update')

def check_api():
    svars = variables()

    file_path = glob.glob(XML_LOCAL_PATH)

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, MAX_FILE_AGE):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True
        
    



##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################


##################################################################################################
# PARSE FUNCTIONS
##################################################################################################



import glob
import os
import xml.etree.ElementTree as ET

from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, DUTCH_INDEX
from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files, download_install_media
from firstimpression.time import change_language, parse_string_to_string
from firstimpression.scala import variables, Log
from firstimpression.api.request import request

##################################################################################################
# LOGGING
##################################################################################################

script = 'Songkick'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['concerts']

MAX_FILE_AGE = 60 * 30

DATE_FORMAT = '%Y-%m-%d'
DATE_FORMAT_NEW = '%a %d %b'
TIME_FORMAT = '%H:%M:%S'
TIME_FORMAT_NEW = '%H:%M'

TAGS = {
    'event': 'results/event',
    'name': 'displayName',
    'type': 'type',
    'age_restriction': 'ageRestriction',
    'start_date': 'start',
    'date': 'date',
    'time': 'time',
    'performance': 'performance/artist',
    'id': 'id',
    'venue': 'venue',
    'location': 'location',
    'city': 'city'
}

##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(api_key, area, max_items):
    debug.log('folder name: {}'.format(NAME))
    url = 'http://api.songkick.com/api/3.0/metro_areas/{}/calendar.xml'.format(area)

    params = {
        'apikey': api_key
    }

    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, '{}.xml'.format(area))

    debug.log('url: {} - temp path: {}'.format(url, xml_temp_path))

    update_directories_api(NAME)
    change_language(DUTCH_INDEX)

    if check_too_old(xml_temp_path, MAX_FILE_AGE):
        response = request(url, params=params)
        root = ET.fromstring(response.content)
        new_root = ET.Element("root")

        for event in root.findall(TAGS['event']):
            item = ET.SubElement(new_root, "event")
            ET.SubElement(item, "name").text = get_name(event)
            ET.SubElement(item, "type").text = get_type(event)
            ET.SubElement(item, "age_restriction").text = get_age_restriction(event)
            ET.SubElement(item, "date").text = parse_string_to_string(get_date(event), DATE_FORMAT, DATE_FORMAT_NEW)
            ET.SubElement(item, "time").text = parse_string_to_string(get_time(event), TIME_FORMAT, TIME_FORMAT_NEW)
            ET.SubElement(item, "performers").text = get_performers(event)
            ET.SubElement(item, "photo").text = get_photo(event)
            ET.SubElement(item, "venue").text = get_venue(event)
            ET.SubElement(item, "location").text = get_location(event)

            if len(new_root) == max_items:
                debug.log('max amount of items breaking')
                break
        
        write_root_to_xml_files(new_root, xml_temp_path, NAME)
    else:
        debug.log('File not old enough to update')

def check_api(area):
    svars = variables()

    file_path = glob.glob(os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, '{}*.xml'.format(area)))

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, MAX_FILE_AGE):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################

def get_photo(event):
    performance = get_performances(event)[0]

    artist_id = get_artist_id(performance)
    link = 'http://images.sk-static.com/images/media/profile_images/artists/{}/large_avatar'.format(artist_id)
    media_link = download_install_media(link, TEMP_FOLDER, NAME, '{}.jpg'.format(artist_id))

    if media_link is None:
        debug.log('No image found using placeholder instead')
        return 'Content:\\placeholders\\img.png'
    else:
        return media_link

##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_name(event):
    return event.get(TAGS['name'], '')

def get_type(event):
    return event.get(TAGS['type'], '')

def get_age_restriction(event):
    return event.get(TAGS['age_restriction'], '')

def get_start_date(event):
    return event.find(TAGS['start_date'])

def get_date(event):
    start_date = get_start_date(event)

    if not start_date is None:
        return start_date.get(TAGS['date'], '')
    else:
        return ''

def get_time(event):
    start_date = get_start_date(event)

    if not start_date is None:
        return start_date.get(TAGS['time'], '')
    else:
        return ''

def get_performances(event):
    return event.findall(TAGS['performance'])

def get_artist_id(performance):
    return performance.get(TAGS['id'], None)

def get_artist_name(performance):
    return performance.get(TAGS['name'], None)

def get_performers(event):
    performances = get_performances(event)
    performers = list()

    for performance in performances:
        artist_id = get_artist_id(performance)

        if not artist_id is None:
            performers.append(get_artist_name(performance))
    
    return ' + '.join(performers)

def get_venue(event):
    return event.find(TAGS['venue']).get(TAGS['name'], '')

def get_location(event):
    return event.find(TAGS['location']).get(TAGS['city'], '').split(',').pop(0)

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################



from firstimpression.api import amber_alert
from firstimpression.api import ams_airport
from firstimpression.api import bbc
from firstimpression.api import chuck_norris
from firstimpression.api import ehv_airport
from firstimpression.api import facebook
from firstimpression.api import google_trends
from firstimpression.api import insta
from firstimpression.api import interia
from firstimpression.api import ns
from firstimpression.api import nu_nl
from firstimpression.api import songkick
from firstimpression.api import traffic
from firstimpression.api import weather
from firstimpression.api import request
from firstimpression.api import solaredge
from firstimpression.api import countdown
from firstimpression.api import twitter



import os
import glob
import xml.etree.ElementTree as ET

from firstimpression.constants import APIS, TEMP_FOLDER, DUTCH_INDEX, LOCAL_INTEGRATED_FOLDER
from firstimpression.file import update_directories_api, check_too_old, download_install_media, write_root_to_xml_files
from firstimpression.time import parse_string_to_string, change_language
from firstimpression.scala import variables, Log
from firstimpression.text import remove_emoji
from firstimpression.api.request import request_json

##################################################################################################
# LOGGING
##################################################################################################

script = 'Facebook'

info = Log('INFO', script)
debug = Log('DEBUG', script)
warn = Log('WARN', script)
error = Log('ERROR', script)

##################################################################################################
# CONSTANTS
##################################################################################################

NAME = APIS['facebook']

DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
DATETIME_FORMAT_NEW = '%d %B %Y'

URL = 'https://fi-api.io/facebook_post/'
BASE_URL_IMAGES = 'https://socials-bucket.s3.eu-central-1.amazonaws.com'

XML_FILENAME = 'facebook.xml'


##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(api_key, max_minutes, max_characters, max_items):
    debug.log('folder name: {}'.format(NAME))
    max_file_age = 60 * max_minutes
    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
    
    debug.log('max_file_age: {} - temp path: {}'.format(max_file_age, xml_temp_path))

    headers = {
        'Authorization': 'Token {}'.format(api_key)
    }

    params = {
        'number_of_posts': max_items
    }

    update_directories_api(NAME)
    change_language(DUTCH_INDEX)

    if check_too_old(xml_temp_path, max_file_age):
        response_json = request_json(URL, headers, params, False)

        root = ET.Element("root")

        for post in response_json:
            item = ET.SubElement(root, "item")
            ET.SubElement(item, "likes").text = str(get_reactions(post)['likes'])
            ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters)
            ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, DATETIME_FORMAT_NEW)

            thumbnail_url = get_image(post)
            if thumbnail_url is None:
                debug.log('image not found using placeholder')
                media_link = 'Content:\\placeholders\\img.png'
            else:
                debug.log(thumbnail_url)
                media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
            
            ET.SubElement(item, "image").text = media_link

        write_root_to_xml_files(root, xml_temp_path, NAME)        
    else:
        debug.log('File not old enough to download new info')

def check_api(max_minutes):
    svars = variables()

    max_file_age = 60 * max_minutes

    debug.log('max_file_age: {}'.format(max_file_age))

    file_name = 'facebook*.xml'
    file_path = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, file_name)

    debug.log('local path: {}'.format(file_path))

    file_path = glob.glob(file_path)

    if len(file_path) > 0:
        file_path = file_path[0]
        debug.log('glob filepath: {}'.format(file_path))

        if check_too_old(file_path, max_file_age):
            svars['skipscript'] = True
            info.log('file too old')
        else:
            svars['skipscript'] = False
    else:
        warn.log('File does not exists')
        svars['skipscript'] = True

##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################

def get_image(post):
    return post.get('image', None)

def get_reactions(post):
    return post.get('reactions', {})

def get_message(post):
    return post.get('message', '')

def get_creation_date(post):
    creation_date = post.get('created_at', None)
    if creation_date is None:
        return None
    else:
        return creation_date[:19]

##################################################################################################
# PARSE FUNCTIONS
##################################################################################################

def crop_message(text, max_length):
    if len(text) > max_length:
        return text[:max_length-3] + "...\nLees verder op Facebook"
    else:
        return text
